@@ -300,7 +300,7 @@ pango_glyph_item_iter_next_cluster (PangoGlyphItemIter *iter)
 	  if (glyphs->log_clusters[glyph_index] != cluster)
 	    {
 	      iter->end_index = item->offset + glyphs->log_clusters[glyph_index];
-	      iter->end_char += g_utf8_strlen (iter->text + iter->start_index,
+	      iter->end_char += pango_utf8_strlen (iter->text + iter->start_index,
 					       iter->end_index - iter->start_index);
 	      break;
 	    }
@@ -323,7 +323,7 @@ pango_glyph_item_iter_next_cluster (PangoGlyphItemIter *iter)
 	  if (glyphs->log_clusters[glyph_index] != cluster)
 	    {
 	      iter->end_index = item->offset + glyphs->log_clusters[glyph_index];
-	      iter->end_char += g_utf8_strlen (iter->text + iter->start_index,
+	      iter->end_char += pango_utf8_strlen (iter->text + iter->start_index,
 					       iter->end_index - iter->start_index);
 	      break;
 	    }
@@ -388,7 +388,7 @@ pango_glyph_item_iter_prev_cluster (PangoGlyphItemIter *iter)
 	    {
 	      glyph_index++;
 	      iter->start_index = item->offset + glyphs->log_clusters[glyph_index];
-	      iter->start_char -= g_utf8_strlen (iter->text + iter->start_index,
+	      iter->start_char -= pango_utf8_strlen (iter->text + iter->start_index,
 						 iter->end_index - iter->start_index);
 	      break;
 	    }
@@ -412,7 +412,7 @@ pango_glyph_item_iter_prev_cluster (PangoGlyphItemIter *iter)
 	    {
 	      glyph_index--;
 	      iter->start_index = item->offset + glyphs->log_clusters[glyph_index];
-	      iter->start_char -= g_utf8_strlen (iter->text + iter->start_index,
+	      iter->start_char -= pango_utf8_strlen (iter->text + iter->start_index,
 						 iter->end_index - iter->start_index);
 	      break;
 	    }
